.. _naming-variables:

##################
 Naming Variables
##################

***************
 Rename Filter
***************

The rename filter is used to rename variables in a dataset.

.. _remapping_option:

******************
 Remapping Option
******************

TODO.
